NLSL: strutl1.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
strutl1.f90 File Reference

I/O UTILITY ROUTINES FOR NLS COMMAND INTERPRETER. More...

Go to the source code of this file.

## Functions/Subroutines
logical function | getlin (line)
| issue a prompt and retreive a line from command stream More...
subroutine | gettkn (line, token, lth)
| Written for free-form input of parameters for slow-motional calculations. Returns a token consisting of nonseparator characters (separators are space, tab, and ',') with all control. More...
subroutine | ungett (token, lth, line)
logical function | ftoken (token, lth, val)
logical function | itoken (token, lth, ival)
integer function | indtkn (line)

## Detailed Description

I/O UTILITY ROUTINES FOR NLS COMMAND INTERPRETER.

Contains four functions and two subroutines:

     getlin  -- issue a prompt, retrieve a line from command stream *

     gettkn  -- extract a token from the given line (subroutine)

     ungett  -- replace a token at the line's beginning (subroutine)

     ftoken  -- returns a real number

     itoken  -- returns an integer number

     indtkn  -- returns an index, i.e., a parenthesized number *

- Note: two of these routines use module stdio. Subroutine touppr and function itrim were moved into strutl2.f90 because they have

  ## more general utility and a different set of dependencies.

Definition in file strutl1.f90.

## Function/Subroutine Documentation

logical function ftoken | ( | character | token,
|  | integer | lth,
|  | double precision | val
| ) |  |

Definition at line 182 of file strutl1.f90.

logical function getlin | ( | character*80 | line | ) |

issue a prompt and retreive a line from command stream

Returns

Definition at line 32 of file strutl1.f90.

Here is the call graph for this function:

subroutine gettkn | ( | character | line,
|  | character | token,
|  | integer | lth
| ) |  |

Written for free-form input of parameters for slow-motional calculations. Returns a token consisting of nonseparator characters (separators are space, tab, and ',') with all control.

characters filtered out. Special cases: '(', ')', '=', '*', and end-of-line, which are returned as single-character tokens.

Definition at line 75 of file strutl1.f90.

Here is the caller graph for this function:

integer function indtkn | ( | character | line | ) |

Definition at line 282 of file strutl1.f90.

Here is the call graph for this function:

logical function itoken | ( | character*30 | token,
|  | integer | lth,
|  | integer | ival
| ) |  |

Definition at line 248 of file strutl1.f90.

subroutine ungett | ( | character | token,
|  | integer | lth,
|  | character | line
| ) |  |

Definition at line 165 of file strutl1.f90.

Here is the caller graph for this function: